FieldKind

Enum FieldKind 

#[repr(i32)]
pub enum FieldKind { FIELD_KIND_UNSPECIFIED = 0, LABEL = 1, ATTRIBUTE = 2, MEASUREMENT = 3, TRACE_ID = 4, SPAN_ID = 5, PARENT_SPAN_ID = 6, TIMESTAMP_NS = 7, DURATION_NS = 8, FORENSIC = 9, }

Variants



FIELD_KIND_UNSPECIFIED = 0



LABEL = 1



ATTRIBUTE = 2



MEASUREMENT = 3



TRACE_ID = 4



SPAN_ID = 5



PARENT_SPAN_ID = 6



TIMESTAMP_NS = 7



DURATION_NS = 8



FORENSIC = 9

Implementations

Source

impl FieldKind

pub const Unspecified: FieldKind = Self::FIELD_KIND_UNSPECIFIED

Short-name alias for FIELD_KIND_UNSPECIFIED.

pub const Label: FieldKind = Self::LABEL

Short-name alias for LABEL.

pub const Attribute: FieldKind = Self::ATTRIBUTE

Short-name alias for ATTRIBUTE.

pub const Measurement: FieldKind = Self::MEASUREMENT

Short-name alias for MEASUREMENT.

pub const TraceId: FieldKind = Self::TRACE_ID

Short-name alias for TRACE_ID.

pub const SpanId: FieldKind = Self::SPAN_ID

Short-name alias for SPAN_ID.

pub const ParentSpanId: FieldKind = Self::PARENT_SPAN_ID

Short-name alias for PARENT_SPAN_ID.

pub const TimestampNs: FieldKind = Self::TIMESTAMP_NS

Short-name alias for TIMESTAMP_NS.

pub const DurationNs: FieldKind = Self::DURATION_NS

Short-name alias for DURATION_NS.

pub const Forensic: FieldKind = Self::FORENSIC

Short-name alias for FORENSIC.

pub const fn as_str(self) -> &'static str

Stable string label.

pub const fn is_envelope_lifted(self) -> bool

True if a value of this kind is lifted from the typed payload to a dedicated envelope slot.